@@ -22,7 +22,7 @@ plotLMER3d.fnc<-function(model=NULL,
 			theta=0,
 			phi=0,
 			contourstepsize=0.2,
-                        legend.args=NULL,
+            legend.args=NULL,
 			play3d=FALSE,   # or TRUE or a list with first element axis, e.g., c(0,0,1), second element rpm, 
 					# e.g., 4, and third element duration, e.g., 20.			
 			ref.surf=FALSE,
@@ -41,22 +41,67 @@ plotLMER3d.fnc<-function(model=NULL,
 		stop("either provide a value to argument ''model'' (an object of class ''mer'') \n 
 			or provide a file name containing plotting information \n")
 	}
+####################################################
+#               DEFINE SOME FUNCTIONS              #
+####################################################
 
-### makeDefaultMatrix.fnc
-makeDefaultMatrix.fnc<-function (model, n = 100, 
-conditioningPred = "", conditioningValue = NULL,
-control = NA) 
+####################################################
+# define function getPos.fnc
+getPos.fnc<-function (vec, pos) 
 {
+    if (pos == "end") 
+        return(length(vec))
+    else {
+        if (pos == "beg") 
+            return(1)
+        else return(floor(length(vec)/2))
+    }
+}
+
+
+####################################################
+# define function getRange.fnc
+getRange.fnc<-function (lst) 
+{
+    v = vector()
+    for (i in 1:length(lst)) {
+        if (is.data.frame(lst[[i]])) {
+            if ("lower" %in% colnames(lst[[i]])) {
+                v = c(v, as.vector(lst[[i]][, c("Y", "lower", 
+                  "upper")]))
+            }
+            else {
+                v = c(v, as.vector(lst[[i]][, "Y"]))
+            }
+        }
+        else {
+            for (j in 1:length(lst[[i]])) {
+                if ("lower" %in% colnames(lst[[i]][[j]])) {
+                  v = c(v, as.vector(lst[[i]][[j]][, c("Y", "lower", 
+                    "upper")]))
+                }
+                else {
+                  v = c(v, as.vector(lst[[i]][[j]][, "Y"]))
+                }
+            }
+        }
+    }
+    return(range(v))
+}
+
+
+####################################################
+# define function makeDefaultMatrix.fnc
+makeDefaultMatrix.fnc<-function (model, n = 100, conditioningPred = "", conditioningValue = NULL, control = NA) {
     coefs = fixef(model)
     ncoefs = length(coefs)
-    X = model@X
-    if (!is.null(names(model@fixef))) {
-        colnames(X) = names(model@fixef)
+    X = getME(model,"X")
+    if (!is.null(names(fixef(model)))) {
+        colnames(X) = names(fixef(model))
     }
     nams = strsplit(names(coefs), ":")
     if (is.character(conditioningValue)) {
-        condName = paste(conditioningPred, conditioningValue, 
-            sep = "")
+        condName = paste(conditioningPred, conditioningValue, sep = "")
     }
     else {
         condName = conditioningPred
@@ -120,18 +165,17 @@ control = NA)
     if (!is.na(control)[[1]]) {
         controlPredName = as.vector(control[[1]])
         if (!is.element(controlPredName, colnames(m))) {
-            stop(paste("the control predictor name", controlPredName, 
-                "is not a valid column name\n", sep = " "))
+            stop(paste("the control predictor name", controlPredName, "is not a valid column name\n", sep = " "))
         }
         else {
-            m[, controlPredName] = rep(as.vector(control[[2]]), 
-                nrow(m))
+            m[, controlPredName] = rep(as.vector(control[[2]]), nrow(m))
         }
     }
     return(m)
 }
 
-### degreesOrKnots.fnc
+####################################################
+# define function degreesOrKnots.fnc
 degreesOrKnots.fnc<-function (name) 
 {
     s = strsplit(name, " ")[[1]][2]
@@ -139,7 +183,18 @@ degreesOrKnots.fnc<-function (name)
     return(as.numeric(s2[[1]][1]))
 }
 
-### implementInteractions.fnc
+
+####################################################
+# define function getKnots.fnc
+getKnots.fnc<-function (colnms, xlb) 
+{
+    pos = grep(paste("rcs\\(", xlb, ",", sep = ""), colnms)
+    tmp = strsplit(colnms[pos[1]], ")")[[1]][1]
+    return(as.numeric(strsplit(tmp, " ")[[1]][2]))
+}
+
+####################################################
+# define function implementInteractions.fnc
 implementInteractions.fnc<-function (m) 
 {
     nams = strsplit(colnames(m), ":")
@@ -154,7 +209,9 @@ implementInteractions.fnc<-function (m)
     return(m)
 }
 
-### transforming.fnc
+
+####################################################
+# define function transforming.fnc
 transforming.fnc<-function (y, fun) 
 {
     if (is.function(fun)) {
@@ -163,7 +220,8 @@ transforming.fnc<-function (y, fun)
     else return(y)
 }
 
-### parsePredName.fnc
+####################################################
+# define function parsePredName.fnc
 parsePredName.fnc<-function (name) 
 {
     s = strsplit(name, "[\\(\\)]")[[1]][2]
@@ -172,22 +230,12 @@ parsePredName.fnc<-function (name)
 }
 
 
-### getKnots.fnc
-getKnots.fnc<-function (colnms, xlb) 
-{
-    pos = grep(paste("rcs\\(", xlb, ",", sep = ""), colnms)
-    tmp = strsplit(colnms[pos[1]], ")")[[1]][1]
-    return(as.numeric(strsplit(tmp, " ")[[1]][2]))
-}
-
-
-### preparePredictor.fnc
-preparePredictor.fnc<-function (pred, model, m, ylabel, fun, val, 
-xlabel, mcmc, ranefs, ...) 
-{
-    X = model@X
-    if (!is.null(names(model@fixef))) {
-        colnames(X) = names(model@fixef)
+####################################################
+# define function makeDefaultMatrix.fnc
+preparePredictor.fnc<-function (pred, model, m, ylabel, fun, val, xlabel, ranefs, ...) {
+    X = getME(model,"X")
+    if (!is.null(names(fixef(model)))) {
+        colnames(X) = names(fixef(model))
     }
     polynomial = FALSE
     namesplit = strsplit(pred, ", ")[[1]]
@@ -236,14 +284,7 @@ xlabel, mcmc, ranefs, ...)
                 m = implementInteractions.fnc(m)
                 vals = m %*% fixefs
                 vals = transforming.fnc(vals, fun)
-                if (!is.na(mcmc[[1]][1])) {
-                  #dfr = cbind(data.frame(X = m[, pred], Y = vals), 
-                    #addMCMCci.fnc(mcmcM = mcmc, model, m, fun, 
-                      #pred))
-                }
-                else {
-                  dfr = data.frame(X = m[, pred], Y = vals)
-                }
+                dfr = data.frame(X = m[, pred], Y = vals)
                 dfr$Predictor = rep(xlabel, nrow(dfr))
                 dfr$Type = rep(isfactor, nrow(dfr))
                 if (is.na(val)) {
@@ -262,8 +303,7 @@ xlabel, mcmc, ranefs, ...)
                 model@frame[, pred] = factor(model@frame[, pred])
             if (is.factor(model@frame[, pred])) {
                 isfactor = TRUE
-                factnames = paste(pred, levels(model@frame[, 
-                  pred])[-1], sep = "")
+                factnames = paste(pred, levels(model@frame[, pred])[-1], sep = "")
                 m = m[1:(length(factnames) + 1), ]
                 for (i in 1:length(factnames)) {
                   m[i + 1, factnames[i]] = 1
@@ -272,13 +312,7 @@ xlabel, mcmc, ranefs, ...)
                 vals = m %*% fixefs
                 vals = transforming.fnc(vals, fun)
                 x = 1:nrow(m)
-                if (!is.na(mcmc[[1]][1])) {
-                  #dfr = cbind(data.frame(X = x, Y = vals), addMCMCci.fnc(mcmcM = mcmc, 
-                    #model, m, fun, pred = factnames[i], factor = TRUE))
-                }
-                else {
-                  dfr = data.frame(X = x, Y = vals)
-                }
+                dfr = data.frame(X = x, Y = vals)
                 dfr$Predictor = rep(xlabel, nrow(dfr))
                 dfr$Type = rep(isfactor, nrow(dfr))
                 if (is.na(val)) {
@@ -325,8 +359,7 @@ xlabel, mcmc, ranefs, ...)
         else {
             namesplit = strsplit(pred, ", ")[[1]]
             name = pred
-            arg2 = as.numeric(substr(namesplit[2], 1, nchar(namesplit[2]) - 
-                1))
+            arg2 = as.numeric(substr(namesplit[2], 1, nchar(namesplit[2]) - 1))
             cat("DIT ZOU DOOD STUK CODE MOETEN ZIJN\n")
         }
         if (polynomial | rcspline) {
@@ -341,8 +374,7 @@ xlabel, mcmc, ranefs, ...)
                 }
                 else {
                   xlabel = pred
-                  vec = paste("poly(", name, ", ", degree, ", raw = TRUE)1", 
-                    sep = "")
+                  vec = paste("poly(", name, ", ", degree, ", raw = TRUE)1", sep = "")
                 }
                 name1 = vec
                 m[, vec] = seq(min(X[, vec]), max(X[, vec]), 
@@ -353,8 +385,7 @@ xlabel, mcmc, ranefs, ...)
                       sep = ""))
                   }
                   else {
-                    vec = c(vec, paste("poly(", name, ", ", degree, 
-                      ", raw = TRUE)", as.character(i), sep = ""))
+                    vec = c(vec, paste("poly(", name, ", ", degree, ", raw = TRUE)", as.character(i), sep = ""))
                   }
                   m[, vec[i]] = m[, vec[i - 1]] * m[, vec[1]]
                 }
@@ -395,14 +426,7 @@ xlabel, mcmc, ranefs, ...)
             m = implementInteractions.fnc(m)
             vals = m %*% fixefs
             vals = transforming.fnc(vals, fun)
-            if (!is.na(mcmc[[1]][1])) {
-                #dfr = cbind(data.frame(X = m[, vec[1]], Y = vals), 
-                  #addMCMCci.fnc(mcmcM = mcmc, model, m, fun, 
-                    #pred, predname = name1))
-            }
-            else {
-                dfr = data.frame(X = m[, vec[1]], Y = vals)
-            }
+            dfr = data.frame(X = m[, vec[1]], Y = vals)
             dfr$Predictor = rep(xlabel, nrow(dfr))
             dfr$Type = rep(isfactor, nrow(dfr))
             if (is.na(val)) {
@@ -419,15 +443,11 @@ xlabel, mcmc, ranefs, ...)
     return(dfr)
 }
 
-### plotLMERTweaked
-plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit = NA, 
-    ilabel = NA, fun = NA, pred = NA, control = NA, ranefs = NA, 
-    n = 100, intr = NA, mcmcMat = NA, lockYlim = TRUE, addlines = FALSE, 
-    withList = FALSE, cexsize = 0.5, linecolor = 1, addToExistingPlot = FALSE, 
-    verbose = TRUE, ...) 
-{
-    if (!is(model, "mer")) {
-        stop("argument should be a mer model object")
+#######################################################################	
+# define function plotLMERTweaked
+plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit = NA, ilabel = NA, fun = NA, pred = NA, control = NA, ranefs = NA, n = 100, intr = NA, lockYlim = TRUE, addlines = FALSE, withList = FALSE, cexsize = 0.5, linecolor = 1, addToExistingPlot = FALSE, verbose = TRUE, ...) {
+    if (!(is(model, "lmerMod") || (is(model, "glmerMod")))) {
+        stop("argument should be a (g)lmerMod object")
     }
     if (!is.na(xlabel[1])) {
         if (!is.character(xlabel)) 
@@ -441,10 +461,6 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
         if ((!is.numeric(ylimit)) | (length(ylimit) != 2)) 
             stop("ylimit should be a two-element numeric vector\n")
     }
-    if (!is.data.frame(mcmcMat)) {
-        if (!is.na(mcmcMat)) 
-            stop("mcmcMat not a valid\n")
-    }
     if (!is.na(intr[1])) {
         if (!is.list(intr)) 
             stop("intr should be a list\n")
@@ -500,13 +516,6 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
             stop("control should be a two-element list\n")
         }
     }
-    if (!is.data.frame(mcmcMat)) {
-        if (!is.na(ranefs[[1]])) {
-            if (!((length(ranefs) == 4) & is.list(ranefs))) {
-                stop("ranefs should be a four-element list\n")
-            }
-        }
-    }
     if (is.na(ylabel)) 
         ylabel = as.character(eval(model@call[2]$formula))[2]
     if (is.na(pred)) {
@@ -564,9 +573,7 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
             m = makeDefaultMatrix.fnc(model, n, conditioningPred, 
                 val, control)
             subplots = list()
-            dfr = preparePredictor.fnc(predictors[i], model, 
-                m, ylabel, fun, val, xlabel = xlabel, mcmc = mcmcMat, 
-                ranefs, lty = 1, col = 0, ...)
+            dfr = preparePredictor.fnc(predictors[i], model, m, ylabel, fun, val, xlabel = xlabel, ranefs, lty = 1, col = 0, ...)
             subplots[[1]] = dfr
             if (verbose == TRUE) {
                 cat("effect sizes (ranges) for the interaction of ", 
@@ -579,8 +586,7 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
                 m = makeDefaultMatrix.fnc(model, n, conditioningPred, 
                   val, control)
                 dfr = preparePredictor.fnc(predictors[i], model, 
-                  m, ylabel, fun, val, mcmc = mcmcMat, ranefs, 
-                  lty = j, xlabel = xlabel, ...)
+                  m, ylabel, fun, val, ranefs, lty = j, xlabel = xlabel, ...)
                 subplots[[j]] = dfr
                 if (verbose == TRUE) {
                   cat("   ", conditioningPred, " = ", val, ": ", 
@@ -593,8 +599,7 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
             lineTypes = 1
             m = makeDefaultMatrix.fnc(model, n, "", NULL, control)
             dfr = preparePredictor.fnc(predictors[i], model, 
-                m, ylabel, fun, val = NA, xlabel = xlabel, mcmc = mcmcMat, 
-                ranefs, ...)
+                m, ylabel, fun, val = NA, xlabel = xlabel, ranefs, ...)
             plots[[i]] = dfr
             if (verbose == TRUE) {
                 cat("effect size (range) for ", predictors[i], 
@@ -618,6 +623,10 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
         return(invisible(plots))
 }
 
+
+###########################################################################
+#                    rest of function continues here                      #
+###########################################################################
 	# set labels if NULL
 	if(is.null(xlab)){
 		xlab=pred
@@ -627,7 +636,6 @@ plotLMERTweaked<-function (model, xlabel = NA, xlabs = NA, ylabel = NA, ylimit =
 		ylab=intr
 	}
 
-
      	options(warn=-1)
 	if(is.null(zlab)){
 		if(try(is.null(model),silent=TRUE)){
